from django.urls import reverse
from arkindex.project.tests import FixtureTestCase
from arkindex.users import providers
from arkindex.users.models import OAuthStatus
from arkindex.users.providers import get_provider
from unittest.mock import MagicMock


class TestProviders(FixtureTestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.creds = cls.user.credentials.get()

    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.provider_mock = MagicMock()
        cls.provider_mock.slug = 'provider-slug'
        cls.provider_mock().credentials = cls.creds
        cls.old_providers = providers.oauth_providers.copy()
        providers.oauth_providers = [cls.provider_mock]

    @classmethod
    def tearDownClass(cls):
        super().tearDownClass()
        providers.oauth_providers = cls.old_providers

    def test_get_provider(self):
        self.assertEqual(get_provider('provider-slug'), self.provider_mock)
        self.assertIsNone(get_provider('doesnotexist'))

    def test_oauth_callback(self):
        self.provider_mock().handle_callback.side_effect = None
        self.client.force_login(self.user)
        self.creds.status = OAuthStatus.Created
        self.creds.save()
        response = self.client.get(
            reverse('api:oauth-callback', kwargs={'provider': 'provider-slug'}),
        )
        self.assertRedirects(response, reverse('credentials'), fetch_redirect_response=False)
        self.assertEqual(self.creds.status, OAuthStatus.Done)

    def test_oauth_callback_error(self):
        self.provider_mock().handle_callback.side_effect = ValueError
        self.client.force_login(self.user)
        self.creds.status = OAuthStatus.Created
        self.creds.save()
        response = self.client.get(
            reverse('api:oauth-callback', kwargs={'provider': 'provider-slug'}),
        )
        self.assertRedirects(response, reverse('credentials'), fetch_redirect_response=False)
        self.assertEqual(self.creds.status, OAuthStatus.Error)
