from unittest.mock import patch
from rest_framework import status
from django.urls import reverse
from django.test import override_settings
from arkindex.project.tests import FixtureAPITestCase


@override_settings(TRANSKRIBUS_EMAIL=None, TRANSKRIBUS_PASSWORD=None)
class TestUpdateTranskribusEmail(FixtureAPITestCase):

    def test_requires_login(self):
        response = self.client.patch(reverse('api:user-transkribus'), {
            'transkribus_email': 'nope@nope.com',
            'transkribus_password': '42'
        }, format='json')
        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)

    @patch('transkribus.TranskribusAPI.login')
    def test_wrong_credentials(self, mock_transkribus):
        mock_transkribus.side_effect = Exception()
        self.client.force_login(self.user)
        response = self.client.patch(reverse('api:user-transkribus'), {
            'transkribus_email': 'nope@nope.com',
            'transkribus_password': '42'
        }, format='json')
        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
        self.assertEqual(response.json(), {"__all__": ["The email or password is incorrect"]})

    @patch('transkribus.TranskribusAPI.login')
    def test_update_transkribus_email(self, mock_transkribus):
        mock_transkribus.return_value = {"email": "nope@nope.com"}
        self.client.force_login(self.user)

        self.assertIsNone(self.user.transkribus_email)
        response = self.client.patch(reverse('api:user-transkribus'), {
            'transkribus_email': 'nope@nope.com',
            'transkribus_password': '42'
        }, format='json')
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        self.user.refresh_from_db()
        self.assertEqual(self.user.transkribus_email, "nope@nope.com")
